YsRecordFile class

Constructors

YsRecordFile({String? begin, String? cameraType, String? end, int? type})
YsRecordFile.fromJson(Map<String, dynamic> json)

Properties

begin ↔ String?
getter/setter pair
cameraType ↔ String?
getter/setter pair
end ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited